@@ -750,14 +750,15 @@ class DerivedDataApi(metaclass=Singleton):
             except Exception as e:
                 print(f'failed to get_fof_nav_calc <err_msg> {e} from {FOFNavCalc.__tablename__}')
 
-    def delete_fof_nav_calc(self, date_to_delete: datetime.date, fof_id_list: List[str]) -> bool:
+    def delete_fof_nav_calc(self, manager_id: str, fof_id: str, date_list: List[datetime.date]) -> bool:
         with DerivedDatabaseConnector().managed_session() as session:
             try:
                 session.query(
                     FOFNavCalc
                 ).filter(
-                    FOFNavCalc.fof_id.in_(fof_id_list),
-                    FOFNavCalc.datetime == date_to_delete,
+                    FOFNavCalc.manager_id == manager_id,
+                    FOFNavCalc.fof_id == fof_id,
+                    FOFNavCalc.datetime.in_(date_list),
                 ).delete(synchronize_session=False)
                 session.commit()
                 return True
@@ -765,11 +766,13 @@ class DerivedDataApi(metaclass=Singleton):
                 print(f'failed to delete data <err_msg> {e} from {FOFNavCalc.__tablename__}')
                 return False
 
-    def get_fof_position(self, fof_id_list: Tuple[str] = ()):
+    def get_fof_position(self, manager_id: str, fof_id_list: Tuple[str] = ()):
         with DerivedDatabaseConnector().managed_session() as session:
             try:
                 query = session.query(
                     FOFPosition,
+                ).filter(
+                    FOFPosition.manager_id == manager_id,
                 )
                 if fof_id_list:
                     query = query.filter(
@@ -779,14 +782,15 @@ class DerivedDataApi(metaclass=Singleton):
             except Exception as e:
                 print(f'failed to get_fof_position <err_msg> {e} from {FOFPosition.__tablename__}')
 
-    def delete_fof_position(self, date_to_delete: datetime.date, fof_id_list: List[str]) -> bool:
+    def delete_fof_position(self, manager_id: str, fof_id: str, date_list: List[datetime.date]) -> bool:
         with DerivedDatabaseConnector().managed_session() as session:
             try:
                 session.query(
                     FOFPosition
                 ).filter(
-                    FOFPosition.fof_id.in_(fof_id_list),
-                    FOFPosition.datetime == date_to_delete,
+                    FOFPosition.manager_id == manager_id,
+                    FOFPosition.fof_id == fof_id,
+                    FOFPosition.datetime.in_(date_list),
                 ).delete(synchronize_session=False)
                 session.commit()
                 return True
@@ -794,11 +798,13 @@ class DerivedDataApi(metaclass=Singleton):
                 print(f'failed to delete data <err_msg> {e} from {FOFPosition.__tablename__}')
                 return False
 
-    def get_fof_investor_data(self, fof_id_list: Tuple[str] = ()):
+    def get_fof_investor_data(self, manager_id: str, fof_id_list: Tuple[str] = ()):
         with DerivedDatabaseConnector().managed_session() as db_session:
             try:
                 query = db_session.query(
                     FOFInvestorData,
+                ).filter(
+                    FOFInvestorData.manager_id == manager_id,
                 )
                 if fof_id_list:
                     query = query.filter(
@@ -808,14 +814,15 @@ class DerivedDataApi(metaclass=Singleton):
             except Exception as e:
                 print(f'failed to get_fof_investor_data <err_msg> {e} from {FOFInvestorData.__tablename__}')
 
-    def delete_fof_investor_data(self, fof_id_to_delete: str, investor_id_list: List[str]) -> bool:
+    def delete_fof_investor_data(self, manager_id: str, fof_id_to_delete: str, investor_id_list: List[str]) -> bool:
         with DerivedDatabaseConnector().managed_session() as session:
             try:
                 session.query(
                     FOFInvestorData
                 ).filter(
-                    FOFInvestorData.investor_id.in_(investor_id_list),
                     FOFInvestorData.fof_id == fof_id_to_delete,
+                    FOFInvestorData.manager_id == manager_id,
+                    FOFInvestorData.investor_id.in_(investor_id_list),
                 ).delete(synchronize_session=False)
                 session.commit()
                 return True
@@ -823,11 +830,13 @@ class DerivedDataApi(metaclass=Singleton):
                 print(f'failed to delete data <err_msg> {e} from {FOFInvestorData.__tablename__}')
                 return False
 
-    def get_fof_position_detail(self, fof_id_list: Tuple[str] = ()):
+    def get_fof_position_detail(self, manager_id: str, fof_id_list: Tuple[str] = ()):
         with DerivedDatabaseConnector().managed_session() as db_session:
             try:
                 query = db_session.query(
                     FOFPositionDetail,
+                ).filter(
+                    FOFPositionDetail.manager_id == manager_id,
                 )
                 if fof_id_list:
                     query = query.filter(
@@ -837,14 +846,15 @@ class DerivedDataApi(metaclass=Singleton):
             except Exception as e:
                 print(f'failed to get_fof_position_detail <err_msg> {e} from {FOFPositionDetail.__tablename__}')
 
-    def delete_fof_position_detail(self, fof_id_to_delete: str, fund_id_list: List[str]) -> bool:
+    def delete_fof_position_detail(self, manager_id: str, fof_id_to_delete: str, fund_id_list: List[str]) -> bool:
         with DerivedDatabaseConnector().managed_session() as session:
             try:
                 session.query(
                     FOFPositionDetail
                 ).filter(
-                    FOFPositionDetail.fund_id.in_(fund_id_list),
                     FOFPositionDetail.fof_id == fof_id_to_delete,
+                    FOFPositionDetail.manager_id == manager_id,
+                    FOFPositionDetail.fund_id.in_(fund_id_list),
                 ).delete(synchronize_session=False)
                 session.commit()
                 return True
@@ -866,7 +876,7 @@ class DerivedDataApi(metaclass=Singleton):
                     )
                 return pd.read_sql(query.statement, query.session.bind)
             except Exception as e:
-                print(f'failed to get_fof_position_detail <err_msg> {e} from {HedgeFundInvestorPurAndRedemp.__tablename__}')
+                print(f'failed to get_hedge_fund_investor_pur_redemp <err_msg> {e} from {HedgeFundInvestorPurAndRedemp.__tablename__}')
 
     def get_hedge_fund_investor_pur_redemp_by_id(self, id: int):
         with DerivedDatabaseConnector().managed_session() as db_session:
@@ -878,7 +888,7 @@ class DerivedDataApi(metaclass=Singleton):
                 )
                 return pd.read_sql(query.statement, query.session.bind)
             except Exception as e:
-                print(f'failed to get_fof_position_detail <err_msg> {e} from {HedgeFundInvestorPurAndRedemp.__tablename__}')
+                print(f'failed to get_hedge_fund_investor_pur_redemp_by_id <err_msg> {e} from {HedgeFundInvestorPurAndRedemp.__tablename__}')
 
     def delete_hedge_fund_investor_pur_redemp(self, id_to_delete: int) -> bool:
         with DerivedDatabaseConnector().managed_session() as session:
@@ -908,7 +918,7 @@ class DerivedDataApi(metaclass=Singleton):
                     )
                 return pd.read_sql(query.statement, query.session.bind)
             except Exception as e:
-                print(f'failed to get_fof_position_detail <err_msg> {e} from {HedgeFundInvestorDivAndCarry.__tablename__}')
+                print(f'failed to get_hedge_fund_investor_div_carry <err_msg> {e} from {HedgeFundInvestorDivAndCarry.__tablename__}')
 
     def delete_hedge_fund_investor_div_carry(self, id_to_delete: int) -> bool:
         with DerivedDatabaseConnector().managed_session() as session:
