@@ -66,7 +66,7 @@ class PortfolioDataApi(metaclass=Singleton):
             }
             return data
         except Exception as e:
-            print(f'Failed to get data <err_msg> {e} from portfolio.get_portfolio_mv')
+            print(f'Failed to get data <err_msg> {e} from portfolio.get_portfolio_nav')
 
 
     def get_portfolio_benchmark_info(self):
@@ -82,6 +82,8 @@ class PortfolioDataApi(metaclass=Singleton):
 
     def get_portfolio_mv(self, fund_nav, index_id, begin_date, end_date, time_para):
         try:
+            def print_st(mdd):
+                return str(round(mdd * 100,2)) + '%' 
             fund_nav.columns=['组合']
             basic = BasicDataApi()
             index_price = basic.get_index_price_dt(index_list=[index_id],start_date=fund_nav.index[0] - datetime.timedelta(days=10),end_date=fund_nav.index[-1]).pivot_table(index='datetime',columns='index_id',values='close')
@@ -93,7 +95,44 @@ class PortfolioDataApi(metaclass=Singleton):
             df = df / df.iloc[0]
             df.loc[:,'价格比'] = df.组合 / df[index_id]
             df = df.rename(columns=name_dic)
-            return df
+            mv_df = df[['组合']].rename(columns={'组合':'mv'})
+            mv_df.index.name = 'date'
+            mdd_details = Calculator.get_mdd_recover_result(mv_df=mv_df)
+            mdd1 = print_st(mdd_details['mdd1'])
+            mdd1_d1 = str(mdd_details['mdd1_d1'])
+            mdd1_d2 = str(mdd_details['mdd1_d2'])
+            mdd1_lens = mdd_details['mdd1_lens']
+            mdd2 = print_st(mdd_details['mdd2'])
+            mdd2_d1 = str(mdd_details['mdd2_d1'])
+            mdd2_d2 = str(mdd_details['mdd2_d2'])
+            mdd2_lens = mdd_details['mdd2_len']
+            bk_stats = Calculator.get_stat_result_from_df(df=mv_df.reset_index(), date_column='date', value_column='mv').__dict__
+            ar = print_st(bk_stats['annualized_ret'])
+            av = print_st(bk_stats['annualized_vol'])
+            sharpe = round(bk_stats['sharpe'],2)
+            st1 = f'年化收益: {ar} 年化波动: {av} 夏普比率: {sharpe}'
+            st2 = f'最大回撤 {mdd1} {mdd1_d1} : {mdd1_d2}, {mdd1_lens} days'
+            st3 = f'第二回撤 {mdd2} {mdd2_d1} : {mdd2_d2}, {mdd2_lens} days'
+            sts = [st1, st2, st3]
+            mdd_dic_1 = {
+                'd1':str(mdd_details['mdd1_d1']),
+                'd2':str(mdd_details['mdd1_d2']),
+                'v1':df['组合'].loc[mdd_details['mdd1_d1']: mdd_details['mdd1_d2']].min(),
+                'v2':df['组合'].loc[mdd_details['mdd1_d1']: mdd_details['mdd1_d2']].max(),
+            }
+            mdd_dic_2 = {
+                'd1':str(mdd_details['mdd2_d1']),
+                'd2':str(mdd_details['mdd2_d2']),
+                'v1':df['组合'].loc[mdd_details['mdd2_d1']: mdd_details['mdd2_d2']].min(),
+                'v2':df['组合'].loc[mdd_details['mdd2_d1']: mdd_details['mdd2_d2']].max(),
+            }
+            data = {
+                'data':df,
+                'mdd_1':mdd_dic_1,
+                'mdd_2':mdd_dic_2,
+                'stats': sts
+            }
+            return data
         except Exception as e:
             print(f'Failed to get data <err_msg> {e} from portfolio.get_portfolio_mv')
 
@@ -236,6 +275,10 @@ class PortfolioDataApi(metaclass=Singleton):
     def get_port_fund_pos_date(self,fund_id, order_list,index_id): 
         try:
             basic = BasicDataApi()
+            fund_list = [fund_id]
+            fund_info = basic.get_fund_info(fund_list=fund_list)
+            desc_name_dic = fund_info.set_index('fund_id').to_dict()['desc_name']
+
             begin_date, end_date = RawDataApi().get_date_range(time_para='ALL', begin_date=None, end_date=None)
             fund_nav = basic.get_fund_nav(fund_list=[fund_id])
             fund_nav = fund_nav.pivot_table(columns='fund_id',index='datetime',values='adjusted_net_value')
@@ -259,14 +302,21 @@ class PortfolioDataApi(metaclass=Singleton):
                     is_empty = False
                 elif not is_empty and r[1] == 0:
                     dic['end_date'] = r[0]
+                    dic['rise'] =  bool(nav_df.loc[:dic['end_date']].iloc[-1][fund_id] > nav_df.loc[dic['begin_date'],fund_id])
+                    dic['begin_date'] = str(dic['begin_date'])
+                    dic['end_date'] = str(dic['end_date'])
                     result.append(dic)
                     dic = {}
                     is_empty = True
             if not is_empty:
                 dic['end_date'] = end_date
+                dic['rise'] =  bool(nav_df.loc[:dic['end_date']].iloc[-1][fund_id] > nav_df.loc[dic['begin_date'],fund_id])
+                dic['begin_date'] = str(dic['begin_date'])
+                dic['end_date'] = str(dic['end_date'])
                 result.append(dic)
+            nav_df.index.name = 'datetime'
             data = {
-                '净值':nav_df,
+                '净值':nav_df.rename(columns=desc_name_dic),
                 '持有期':result}
             return data
         except Exception as e:
@@ -285,6 +335,9 @@ class PortfolioDataApi(metaclass=Singleton):
     def get_port_ret_resolve(self, share_list , begin_date , end_date):
         try:
             basic = BasicDataApi()
+            fund_list = list(set([i for dt, share_list in share_list.items() for i in list(share_list.keys())]))
+            fund_info = basic.get_fund_info(fund_list=fund_list)
+            desc_name_dic = fund_info.set_index('fund_id').to_dict()['desc_name']
             all_ret_dict = []
             for i in range(len(list(share_list.keys()))):
                 this_date = list(share_list.keys())[i]
@@ -312,7 +365,7 @@ class PortfolioDataApi(metaclass=Singleton):
                     fund_nav = basic.get_fund_nav_with_date(start_date=cal_start,end_date=cal_end,fund_list=[fund_id])
                     fund_nav = fund_nav.pivot_table(index="datetime" , values="adjusted_net_value" , columns="fund_id").dropna()
                     fund_ret = round((fund_nav.iloc[-1].values[0] * fund_share - fund_nav.iloc[0].values[0] * fund_share)*100,2)
-                    ret_dict[fund_id] = fund_ret
+                    ret_dict[desc_name_dic[fund_id]] = fund_ret
                 all_ret_dict.append(ret_dict)
             return all_ret_dict
         except Exception as e:
@@ -326,9 +379,18 @@ class PortfolioDataApi(metaclass=Singleton):
             result = {}
             for types, fund_list in fund_type.items():
                 result[types] = [name_dic[_] for _ in fund_list]
+
+            _result = []
+            for type_i, fund_list in result.items():
+                _df = fund_wgt[fund_list].sum(axis=1)
+                _df.name = type_i
+                _result.append(_df)
+            fund_type_wgt = pd.concat(_result,axis=1)
+
             data = {
-                '权重':fund_wgt,
-                '类型':result,
+                '基金':fund_wgt,
+                '类型':fund_type_wgt,
+                '类型对照':result,
             }
             return data
         except Exception as e:
