@@ -614,7 +614,10 @@ class FundIndicatorProcessorGroup:
         # excess return against mmf
         _ex_return_mmf = df_i_mmf[:, 0] - df_i_mmf[:, 1]
         # winning rate against mmf
-        winning_rate = len(_ex_return_mmf[_ex_return_mmf > 0]) / len(_ex_return_mmf)
+        if len(_ex_return_mmf) != 0:
+            winning_rate = len(_ex_return_mmf[_ex_return_mmf > 0]) / len(_ex_return_mmf)
+        else:
+            winning_rate = 0
         # track error
         track_err = np.nanstd(_ex_return, ddof=1) * np.sqrt(self._TRADING_DAYS_PER_YEAR)
         # track error agains hs300
@@ -776,7 +779,7 @@ class FundIndicatorProcessorGroup:
 
 
 if __name__ == '__main__':
-    date = '20200930'
+    date = '20210129'
     fipg = FundIndicatorProcessorGroup(DerivedDataHelper(), 5)
     fipg.process(date, date, pd.to_datetime(date).date())
     # FundIndicatorProcessorGroup.update_history('20201009', 5)
