@@ -28,9 +28,9 @@ class ManagerProcessor:
         self.mng_index_list: Dict[str, pd.DataFrame] = {}  # 基金经理指数
         self.mng_indicator_list: Dict[str, pd.DataFrame] = {}  # 基金经理评分
 
-    def init(self, start_date=str, end_date=str, print_time=False, is_mng_index=False, is_mng_indicator=False):
-        self.start_date = start_date if isinstance(start_date, datetime.datetime) else datetime.datetime.strptime(start_date,'%Y-%m-%d').date()
-        self.end_date = end_date if isinstance(end_date, datetime.datetime) else datetime.datetime.strptime(end_date,'%Y-%m-%d').date()
+    def init(self, start_date: str, end_date: datetime.date, print_time=False, is_mng_index=False, is_mng_indicator=False):
+        self.start_date = start_date if isinstance(start_date, datetime.date) else pd.to_datetime(start_date, infer_datetime_format=True).date()
+        self.end_date = end_date if isinstance(end_date, datetime.date) else pd.to_datetime(end_date, infer_datetime_format=True).date()
 
         with BasicDatabaseConnector().managed_session() as quant_session:
             # 交易日序列
@@ -357,7 +357,7 @@ class ManagerProcessor:
             self.class_fund[class_name] = self.fund_info[self.fund_info['wind_class_2'].isin(FUND_CLASSIFIER[class_name])].fund_id
         self._calc_part3(eval_date_dt)
 
-    def do_index_history(self, start_date: str, end_date: str, history: bool = False) -> List[str]:
+    def do_index_history(self, start_date: str, end_date: datetime.date, history: bool = False) -> List[str]:
         self.init(start_date, end_date, is_mng_index=True)
         print('init done, to calc manager index')
         self.calc_index()
@@ -372,7 +372,7 @@ class ManagerProcessor:
         failed_tasks = []
         try:
             end_date_dt: datetime.date = pd.to_datetime(end_date, infer_datetime_format=True).date()
-            self.do_index_history('2005-01-01', end_date_dt.isoformat())
+            self.do_index_history('2005-01-01', end_date_dt)
             self.do_score_update(end_date_dt)
         except Exception as e:
             print(e)
@@ -383,6 +383,6 @@ class ManagerProcessor:
 
 if __name__ == '__main__':
     fmis = ManagerProcessor(DerivedDataHelper())
-    # fmis.process('2020-09-10')
+    fmis.process('20210128')
     # fmis.do_index_history(start_date='2005-01-01', end_date='2020-09-07', eval_date='2020-09-07', eval_start_date='2005-01-01')
-    # fmis.do_score_history(start_date='2005-01-01', end_date='2020-09-07')
\ No newline at end of file
+    # fmis.do_score_history(start_date='2005-01-01', end_date='2020-09-07')
