@@ -134,7 +134,7 @@ class FOFDataManagerLite(metaclass=Singleton):
             df = pd.DataFrame(datas_to_calc_v[row.fund_id], columns=['fund_id', 'datetime', 'unit_total', 'water_line'])
             if df.empty:
                 continue
-            v_nav = FOFDataManagerLite._do_calc_v_net_value(row.net_asset_value, df.unit_total, row.acc_unit_value, df.water_line, incentive_fee_ratio[row.fund_id], v_nav_decimals[row.fund_id])
+            v_nav = FOFDataManagerLite._do_calc_v_net_value(row.net_asset_value, df.unit_total.iloc[[-1]], row.acc_unit_value, df.water_line.iloc[[-1]], incentive_fee_ratio[row.fund_id], v_nav_decimals[row.fund_id])
             v_nav_result.append({'datetime': row.Index, 'fund_id': row.fund_id, 'v_nav': v_nav})
         df = pd.DataFrame.from_dict(v_nav_result)
         if not df.empty:
@@ -240,7 +240,9 @@ class FOFDataManagerLite(metaclass=Singleton):
             # 我们自己算一下虚拟净值 然后拿它对_hedge_nav查缺补漏
             v_nav_calcd = FOFDataManagerLite._calc_virtual_net_value(manager_id, fof_id, hedge_fund_list, self._asset_allocation)
             # 最后再ffill
-            self._hedge_nav = self._hedge_nav.combine_first(v_nav_calcd.reindex(index=self._date_list)).ffill()
+            # self._hedge_nav = self._hedge_nav.combine_first(v_nav_calcd.reindex(index=self._date_list)).ffill()
+            # TODO: 这里虚拟净值只能先全用自己算的
+            self._hedge_nav = v_nav_calcd.reindex(index=self._date_list).ffill()
             if debug_mode:
                 print(self._hedge_nav)
             self._hedge_latest_v_nav = self._hedge_nav.iloc[-1, :]
@@ -248,7 +250,7 @@ class FOFDataManagerLite(metaclass=Singleton):
             self._all_latest_nav = None
             self._latest_nav_date = None
             self._all_latest_acc_nav = None
-            self._hedge_latest_v_nav = pd.Series()
+            self._hedge_latest_v_nav = None
 
         # 获取人工手工校正信息
         manually = BasicDataApi().get_fof_assert_correct(manager_id, fof_id)
@@ -568,8 +570,16 @@ class FOFDataManagerLite(metaclass=Singleton):
             total_ret = None
             total_rr = None
 
-        fof_position_details_list = [self._latest_nav_date.rename('datetime'), asset_type, all_pos, total_ret.rename('total_ret') if total_ret is not None else None, total_rr.rename('total_rr') if total_rr is not None else None, self._total_cost.rename('total_cost'), self._all_latest_nav.rename('nav'),
-                                     self._all_latest_acc_nav.rename('acc_nav'), self._hedge_latest_v_nav.rename('v_nav'), latest_mv.rename('latest_mv') if latest_mv is not None else None]
+        fof_position_details_list = [self._latest_nav_date.rename('datetime') if self._latest_nav_date is not None else pd.Series(name='datetime'),
+                                     asset_type if asset_type is not None else pd.Series(name='asset_type'),
+                                     all_pos if all_pos is not None else pd.Series(name='total_shares'),
+                                     total_ret.rename('total_ret') if total_ret is not None else pd.Series(name='total_ret'),
+                                     total_rr.rename('total_rr') if total_rr is not None else pd.Series(name='total_rr'),
+                                     self._total_cost.rename('total_cost') if self._total_cost is not None else pd.Series(name='total_cost'),
+                                     self._all_latest_nav.rename('nav') if self._all_latest_nav is not None else pd.Series(name='nav'),
+                                     self._all_latest_acc_nav.rename('acc_nav') if self._all_latest_acc_nav is not None else pd.Series(name='acc_nav'),
+                                     self._hedge_latest_v_nav.rename('v_nav') if self._hedge_latest_v_nav is not None else pd.Series(name='v_nav'),
+                                     latest_mv.rename('latest_mv') if latest_mv is not None else pd.Series(name='latest_mv')]
         self._fof_position_details = self._water_line_and_confirmed_nav.join(fof_position_details_list, how='outer')
         self._fof_position_details = self._fof_position_details.rename_axis(index='fund_id').reset_index()
         self._fof_position_details['fof_id'] = fof_id
@@ -707,25 +717,25 @@ class FOFDataManagerLite(metaclass=Singleton):
         else:
             print('[dump_fof_nav_and_pos_to_db] get investor summary failed')
 
-        ret = True
-        if ret:
-            if res_status is not None:
-                try:
-                    fof_data = {
-                        'start_date': res_status.start_date.isoformat(),
-                        'days': (fof_nav.index.array[-1] - res_status.start_date).days,
-                        'mv': mv,
-                        'nav': round(nav, 4),
-                        'total_ret': f'{round(total_ret * 100, 2)}%',
-                        'sharpe': round(res_status.sharpe, 6),
-                        'annualized_ret': f'{round(res_status.annualized_ret * 100, 2)}%',
-                        'mdd': f'{round(res_status.mdd * 100, 2)}%',
-                        'annualized_vol': round(res_status.annualized_vol, 6),
-                    }
-                    self._wechat_bot.send_fof_info(fof_id, fof_nav.index.array[-1], fof_data)
-                except Exception as e:
-                    traceback.print_exc()
-                    self._wechat_bot.send_fof_info_failed(fof_id, e)
+        # ret = True
+        # if ret:
+        #     if res_status is not None:
+        #         try:
+        #             fof_data = {
+        #                 'start_date': res_status.start_date.isoformat(),
+        #                 'days': (fof_nav.index.array[-1] - res_status.start_date).days,
+        #                 'mv': mv,
+        #                 'nav': round(nav, 4),
+        #                 'total_ret': f'{round(total_ret * 100, 2)}%',
+        #                 'sharpe': round(res_status.sharpe, 6),
+        #                 'annualized_ret': f'{round(res_status.annualized_ret * 100, 2)}%',
+        #                 'mdd': f'{round(res_status.mdd * 100, 2)}%',
+        #                 'annualized_vol': round(res_status.annualized_vol, 6),
+        #             }
+        #             self._wechat_bot.send_fof_info(fof_id, fof_nav.index.array[-1], fof_data)
+        #         except Exception as e:
+        #             traceback.print_exc()
+        #             self._wechat_bot.send_fof_info_failed(fof_id, e)
 
         # 把 is_calculating 的标记置为false
         Session = sessionmaker(BasicDatabaseConnector().get_engine())
