@@ -4,15 +4,21 @@ from typing import Optional, List, Dict, Any
 import os
 import traceback
 import time
+import datetime
 
+from sqlalchemy.orm import sessionmaker
 import pandas as pd
+import numpy as np
 
 from ...util.mail_retriever import MailAttachmentRetriever, UID_FILE_NAME
 from ...util.wechat_bot import WechatBot
-from ..wrapper.mysql import DerivedDatabaseConnector
+from ...util.calculator import Calculator
+from ..wrapper.mysql import BasicDatabaseConnector, DerivedDatabaseConnector
 from ..view.derived_models import FOFNav
 from ..api.basic import BasicDataApi
 from ..api.derived import DerivedDataApi
+from ..view.basic_models import FOFInfo
+from ..manager.manager_fof import FOFDataManager
 
 
 class FOFNAVReader:
@@ -185,7 +191,7 @@ class FOFNAVReader:
 
         if df_list:
             try:
-                whole_df = pd.concat(df_list).set_index('fof_id')
+                whole_df = pd.concat(df_list) #.set_index('fof_id')
                 print(whole_df)
                 # self._wechat_bot.send_hedge_fund_nav_update(whole_df)
             except Exception as e:
@@ -200,6 +206,53 @@ class FOFNAVReader:
         if uid_last_succeed is not None:
             with open(os.path.join(self._read_dir, UID_FILE_NAME), 'wb') as f:
                 f.write(uid_last_succeed)
+
+            print(f'[read_navs_and_dump_to_db] to update fof info (manager_id){self._manager_id} (fof_id){self._fof_id}')
+            fof_nav = DerivedDataApi().get_fof_nav(self._manager_id, [self._fof_id])
+            if fof_nav is not None and not fof_nav.empty:
+                fof_nav = fof_nav.drop(columns=['update_time', 'create_time', 'is_deleted']).set_index('datetime').sort_index()
+                fof_latest_acc_nav = fof_nav.acc_net_value.array[-1]
+                fof_latest_adjusted_nav = fof_nav.adjusted_nav.array[-1]
+                nav_of_fof = fof_nav.nav
+                nav = nav_of_fof.array[-1]
+                total_ret = nav_of_fof.array[-1] / nav_of_fof.array[0] - 1
+                res_status = Calculator.get_stat_result(nav_of_fof.index, nav_of_fof.array)
+                last_year_nav = nav_of_fof[nav_of_fof.index < datetime.date(nav_of_fof.index.array[-1].year, 1, 1)]
+                if not last_year_nav.empty:
+                    ret_year_to_now = nav_of_fof.array[-1] / last_year_nav.array[-1] - 1
+                else:
+                    ret_year_to_now = np.nan
+
+                Session = sessionmaker(BasicDatabaseConnector().get_engine())
+                db_session = Session()
+                fof_info_to_set = db_session.query(FOFInfo).filter((FOFInfo.manager_id == self._manager_id) & (FOFInfo.fof_id == self._fof_id)).one_or_none()
+                fof_info_to_set.net_asset_value = float(nav) if not pd.isnull(nav) else None
+                fof_info_to_set.acc_unit_value = float(fof_latest_acc_nav) if not pd.isnull(fof_latest_acc_nav) else None
+                fof_info_to_set.adjusted_net_value = float(fof_latest_adjusted_nav) if not pd.isnull(fof_latest_adjusted_nav) else None
+                # fof_info_to_set.total_volume = float(self._total_shares) if not pd.isnull(self._total_shares) else None
+                # fof_info_to_set.total_amount = float(self._total_net_assets) if not pd.isnull(self._total_net_assets) else None
+                fof_info_to_set.latest_cal_date = nav_of_fof.index.array[-1]
+                fof_info_to_set.ret_year_to_now = float(ret_year_to_now) if not pd.isnull(ret_year_to_now) else None
+                fof_info_to_set.ret_total = float(total_ret) if not pd.isnull(total_ret) else None
+                fof_info_to_set.ret_ann = float(res_status.annualized_ret)
+                fof_info_to_set.mdd = float(res_status.mdd)
+                fof_info_to_set.sharpe = float(res_status.sharpe)
+                fof_info_to_set.vol = float(res_status.annualized_vol)
+                db_session.commit()
+                db_session.close()
+
+                if whole_df is not None:
+                    print(f'[read_navs_and_dump_to_db] to calc and update adj net value (manager_id){self._manager_id} (fof_id){self._fof_id}')
+                    adj_nav = FOFDataManager._calc_adj_nav_for_a_fund(fof_nav.reset_index().rename(columns={'fof_id': 'fund_id', 'nav': 'net_asset_value', 'acc_net_value': 'acc_unit_value'}))
+                    if not adj_nav.empty and not pd.isnull(adj_nav.ta_factor):
+                        print(adj_nav)
+                        Session = sessionmaker(DerivedDatabaseConnector().get_engine())
+                        db_session = Session()
+                        hedge_fund_nav_to_set = db_session.query(FOFNav).filter(FOFNav.fof_id == self._fof_id, FOFNav.manager_id == self._manager_id, FOFNav.datetime == adj_nav.datetime).one_or_none()
+                        hedge_fund_nav_to_set.ta_factor = adj_nav.ta_factor
+                        hedge_fund_nav_to_set.adjusted_net_value = adj_nav.adj_nav
+                        db_session.commit()
+                        db_session.close()
             return whole_df
         return
 
@@ -219,7 +272,7 @@ class FOFNAVReader:
         now_df = DerivedDataApi().get_fof_nav(self._manager_id, [self._fof_id])
         if now_df is not None and not now_df.empty:
             # 同产品同日期的净值如果已经存在了且没有变化，就不写DB了
-            now_df = now_df.drop(columns=['update_time', 'create_time', 'is_deleted', 'volume', 'mv', 'ret']).sort_values(by=['fof_id', 'datetime']).drop_duplicates(subset=['fof_id', 'datetime'], keep='last')
+            now_df = now_df.drop(columns=['update_time', 'create_time', 'is_deleted', 'volume', 'mv', 'ret', 'ta_factor']).sort_values(by=['fof_id', 'datetime']).drop_duplicates(subset=['fof_id', 'datetime'], keep='last')
             now_df = now_df.astype({'nav': 'float64', 'acc_net_value': 'float64', 'adjusted_nav': 'float64'})
             df = df.reindex(columns=now_df.columns).astype(now_df.dtypes.to_dict())
             df = df.merge(now_df, how='left', on=['manager_id', 'fof_id', 'datetime', 'nav', 'acc_net_value'], indicator=True, validate='one_to_one')
@@ -257,6 +310,8 @@ if __name__ == '__main__':
         }
     )
     for one in res.json()['data']:
+        if one['fof_id'] != 'SLW695':
+            continue
         print(one)
         fof_nav_r = FOFNAVReader(one)
         fof_nav_r.read_navs_and_dump_to_db()
