@@ -126,12 +126,12 @@ class WechatBot(object):
         self.send(markdown_content)
 
     def send_hedge_fund_nav_update(self, df: pd.DataFrame):
-        markdown_content = '#### <font color=\"info\">更新以下私募基金净值数据成功</font>'
+        markdown_content = '#### <font color=\"info\">更新以下产品净值数据成功</font>'
         markdown_content += f'\n>{df.to_markdown()}'
         self.send(markdown_content)
 
     def send_hedge_fund_nav_update_failed(self, err_msg: str):
-        markdown_content = '#### <font color=\"warning\">更新私募基金净值数据错误！！</font>'
+        markdown_content = '#### <font color=\"warning\">更新产品净值数据错误！！</font>'
         markdown_content += f'\n>**err msg:** {err_msg}'
         self.send(markdown_content)
 
